@@ -9,8 +9,8 @@ from authlib.oauth2 import (
 )
 from authlib.oauth2.rfc6749 import (
     MissingAuthorizationError,
-    HttpRequest,
 )
+from .requests import FlaskJsonRequest
 from .signals import token_authenticated
 from .errors import raise_http_exception
 
@@ -31,12 +31,6 @@ class ResourceProtector(_ResourceProtector):
             def authenticate_token(self, token_string):
                 return Token.query.filter_by(access_token=token_string).first()
 
-            def request_invalid(self, request):
-                return False
-
-            def token_revoked(self, token):
-                return False
-
         require_oauth.register_token_validator(MyBearerTokenValidator())
 
         # protect resource with require_oauth
@@ -44,7 +38,7 @@ class ResourceProtector(_ResourceProtector):
         @app.route('/user')
         @require_oauth(['profile'])
         def user_profile():
-            user = User.query.get(current_token.user_id)
+            user = User.get(current_token.user_id)
             return jsonify(user.to_dict())
 
     """
@@ -60,23 +54,19 @@ class ResourceProtector(_ResourceProtector):
         headers = error.get_headers()
         raise_http_exception(status, body, headers)
 
-    def acquire_token(self, scopes=None):
+    def acquire_token(self, scopes=None, **kwargs):
         """A method to acquire current valid token with the given scope.
 
         :param scopes: a list of scope values
         :return: token object
         """
-        request = HttpRequest(
-            _req.method,
-            _req.full_path,
-            None,
-            _req.headers
-        )
-        request.req = _req
-        # backward compatible
-        if isinstance(scopes, str):
-            scopes = [scopes]
-        token = self.validate_request(scopes, request)
+        request = FlaskJsonRequest(_req)
+        # backward compatibility
+        kwargs['scopes'] = scopes
+        for claim in kwargs:
+            if isinstance(kwargs[claim], str):
+                kwargs[claim] = [kwargs[claim]]
+        token = self.validate_request(request=request, **kwargs)
         token_authenticated.send(self, token=token)
         g.authlib_server_oauth2_token = token
         return token
@@ -89,7 +79,7 @@ class ResourceProtector(_ResourceProtector):
             @app.route('/api/user')
             def user_api():
                 with require_oauth.acquire('profile') as token:
-                    user = User.query.get(token.user_id)
+                    user = User.get(token.user_id)
                     return jsonify(user.to_dict())
         """
         try:
@@ -97,12 +87,15 @@ class ResourceProtector(_ResourceProtector):
         except OAuth2Error as error:
             self.raise_error_response(error)
 
-    def __call__(self, scopes=None, optional=False):
+    def __call__(self, scopes=None, optional=False, **kwargs):
+        claims = kwargs
+        # backward compatibility
+        claims['scopes'] = scopes
         def wrapper(f):
             @functools.wraps(f)
             def decorated(*args, **kwargs):
                 try:
-                    self.acquire_token(scopes)
+                    self.acquire_token(**claims)
                 except MissingAuthorizationError as error:
                     if optional:
                         return f(*args, **kwargs)
